@@ -1,5 +1,5 @@
 import os
-VERSION='0.3.0r2'
+VERSION='0.3.4'
 PREFIX='/usr/'
 locale_install_dir=os.path.join('${prefix}/share'.replace("${prefix}",PREFIX), 'locale')
 
@@ -15,17 +15,22 @@ default_values=[15,     #framerate
                 0,          #delay ,unused on 0.3
                 1,          #no of channels
                 22050,      #frequency
-                'hw:0,0',   #device
+                'DEFAULT',  #device
                 63,         #video quality
                 10,         #audio quality
                 "$DISPLAY", #display, this is not interpreted as an env variable
                             #but when the value is set to this the argument is omitted
                 0,          #shared memory,0 on 1 off
-                1,          #drop frames,unused in 0.3,0 on 1 off
-                75,         #shared threshold
+                1,          #drop frames,unused in 0.3,0, removed at 0.3.4, preserved for compatibility of prefs file.
+                75,         #shared threshold.Removed at 0.3.4, preserved for compatibility of prefs file.
                 1,          #quick subsampling,0 on 1 off
                 "/tmp",     #working directory
                 1,          #on the fly encoding,0 on 1 off
                 1,          #zero compression,0 on 1 off
-                False       #overwrite existing files
-                ]
\ No newline at end of file
+                False,      #overwrite existing files
+                0,          #include window decorations, 0 on 1 off
+                False,      #Use jack
+                [],         #jack ports
+                0,          #tooltips,0 on 1 off
+                0,          #draw an on-screen frame, surrounding the capture area,0 on 1 off
+                ]
